(*******************************************************************************
tBmDelay v1.0

Derived from
    tComponent

Properties
    Property Duration : duration for delay

Inherited properties
    all properties from tComponent.

methods
    Wait            : Wait.
    WaitforDuration : Set duration property, and wait.

Events
    all events from tComponent.

*******************************************************************************
Author name=BOURMAD Mehdi
Author E-mail=bourmad@multimania.com
Author URL=www.multimania.com/bourmad
*******************************************************************************)

{If you have problems with these lines, remove them and mail me
 which compiler you have. I will correct it for future versions}
{$IFDEF WIN32} {Only for 32 bits compilers}
  {$IFNDEF VER90} {Doesn't works with Delphi 2}
    {$IFNDEF VER100} {Doesn't works with Delphi 3}
      {$ObjExportAll On} {export all objects (for C++Builder 3.0)}
    {$ENDIF}
  {$ENDIF}
{$ENDIF}

unit BmDelay;

interface

uses
  WinTypes, WinProcs, Classes, Dialogs, DsgnIntf, ExtCtrls, Forms, SysUtils;

type
  {*********** tAboutMeProperty ************}
  TAboutMeProperty = class(TPropertyEditor)
  public
    procedure Edit; override;
    function GetAttributes: TPropertyAttributes; override;
    function GetValue: string; override;
  end;

  {*********** tBmAlias ************}
  TBmDelay = class(TComponent)
  private
  { Private declarations }
    FTimer : tTimer;
    FAbout : TAboutMeProperty;
  protected
  { Protected declarations }
    function GetDuration : Integer;
    procedure SetDuration (aValue : Integer);
    procedure OnTimer(Sender: TObject);
  public
    { Public declarations }
    constructor Create (aOwner: TComponent); override;
    Destructor Destroy; override;
    procedure Wait;
    procedure WaitForDelay (aDuration : Integer);
  published
    { Published declarations }
    Property About: TAboutMeProperty read FAbout write FAbout;
    Property Duration: Integer Read GetDuration Write SetDuration default 1000;
  end;

procedure BmWaitForDelay (aDuration : Integer);

procedure Register;

{$IFNDEF WIN32}
  {$R *.D16}
{$ELSE}
  {$R *.D32}
{$ENDIF}

implementation

{************************* tAboutMeProperty component *************************}
procedure TAboutMeProperty.Edit;
begin
  Application.MessageBox ('tBmDelay component v1.0.'
                         +#13#10'This component is freeware.'
                         +#13#10' 1999 BOURMAD Mehdi'
                         +#13#10'http://www.multimania.com/bourmad'
                         +#13#10'mailto:bourmad@multimania.com',
                         'About',
                         MB_OK+ MB_ICONINFORMATION);
end;

function TAboutMeProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paMultiSelect, paDialog, paReadOnly];
end;

function TAboutMeProperty.GetValue: string;
begin
  Result := '(about)';
end;

{************************* TBmAlias component *************************}
constructor TBmDelay.Create;
begin
  inherited Create (aOwner);
  fTimer := tTimer.Create (nil);
  fTimer.Enabled := False;
  fTimer.OnTimer := OnTimer;
  SetDuration (1000); 
end;

destructor TBmDelay.Destroy;
begin
  fTimer.Free;
  inherited Destroy;
end;

function TBmDelay.GetDuration : Integer;
begin
  Result := fTimer.Interval;
end;

procedure TBmDelay.SetDuration (aValue : Integer);
begin
  fTimer.Interval := aValue;
end;

procedure TBmDelay.OnTimer(Sender: TObject);
begin
  fTimer.Enabled := False;
end;

procedure TBmDelay.Wait;
begin
  fTimer.Enabled := True;
  repeat
    Application.ProcessMessages;
  until not fTimer.Enabled;
end;

procedure TBmDelay.WaitForDelay (aDuration : Integer);
begin
  SetDuration (aDuration);
  Wait;
end;

procedure BmWaitForDelay (aDuration : Integer);
var
  aBmDelay : tBmDelay;
begin
  aBmDelay := tBmDelay.Create(nil);
  aBmDelay.WaitForDelay(aDuration);
  aBmDelay.Free;
end;

procedure Register;
begin
  RegisterPropertyEditor (TypeInfo(TAboutMeProperty), TBmDelay,
                          'ABOUT', TAboutMeProperty);
  RegisterComponents('BmSuite', [TBmDelay]);
end;

end.
